@@ -8,7 +8,7 @@ package Future::AsyncAwait;
 use strict;
 use warnings;
 
-our $VERSION = '0.34_002';
+our $VERSION = '0.37_001';
 
 use Carp;
 
@@ -310,6 +310,9 @@ subclass-respecting semantics of L<Future/new> will remain in effect there. As
 such it is not usually necessary to use this feature just for wrapping event
 system modules or other similar situations.
 
+Such an alternative subclass should implement the API documented by
+L<Future::AsyncAwait::Awaitable>.
+
 =head1 WITH OTHER MODULES
 
 =head2 Syntax::Keyword::Try
