@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2019 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2019-2020 -- leonerd@leonerd.org.uk
 
 package Future::AsyncAwait::Awaitable;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.34_002';
+our $VERSION = '0.37_001';
 
 =head1 NAME
 
@@ -34,6 +34,12 @@ requires the following named methods. The role supplies no code to the applied
 class, but can be useful for checking that you have in fact implemented all of
 the required methods.
 
+=head2 Conformance Test
+
+To assist implementors of alternative future-like classes, an API conformance
+test suite is provided by L<Test::Future::AsyncAwait::Awaitable>. You may find
+this useful to check that your implementation is suitable.
+
 =cut
 
 if( defined eval { require Role::Tiny } ) {
@@ -79,13 +85,15 @@ ready and invoking the L</AWAIT_GET> method will throw the given exception.
 =head2 AWAIT_CLONE
 
 Generate a new pending future of the same type as an existing one, which is
-not modified by doing so.
+not modified by doing so. It will only be invoked on instances that are
+currently pending.
 
    $new_f = $f->AWAIT_CLONE
 
 If the instance has any fields that are required for successful operation
 (such as application-wide context or event system components) these ought to
-be copied. The method should not 
+be copied. The method should not otherwise copy any per-instance state such
+as pending callbacks or partial results.
 
 =head2 AWAIT_DONE
 
@@ -121,6 +129,11 @@ successful or failed.
 
    $bool = $f->AWAIT_IS_CANCELLED
 
+An implementation that does not support cancellation can simply return a
+constant false here:
+
+   sub AWAIT_IS_CANCELLED { 0 }
+
 =head2 AWAIT_GET
 
 Yields the result of a successful future (or just the first value if called in
@@ -141,11 +154,19 @@ are unspecified.
 
 =head2 AWAIT_ON_CANCEL
 
-Attach a new CODE reference to be invoked when the future is cancelled. The
-arguments and context that C<$code> is invoked with are unspecified.
+Attach a future instance to be cancelled when another one is cancelled.
 
    $f1->AWAIT_ON_CANCEL( $f2 )
 
+When C<$f1> is cancelled, then C<$f2> is cancelled. There is no link from
+C<$f2> back to C<$f1> - whenever C<$f2> changes state here, nothing special
+happens to C<$f1>.
+
+An implementation that does not support cancellation can simply ignore this
+method.
+
+   sub AWAIT_ON_CANCEL { }
+
 =cut
 
 =head1 AUTHOR
